@@ -147,11 +147,26 @@ DrawingGsk::flush_glyph_string(PangoFont *font,
 
 
 void
-DrawingGsk::draw_text_internal(TextRequest* requests,
-                               gsize n_requests,
-                               uint32_t attr,
-                               vte::color::rgb const* color)
+DrawingGsk::draw_text(TextRequest* requests,
+                      gsize n_requests,
+                      uint32_t attr,
+                      vte::color::rgb const* color)
 {
+        if (_vte_debug_on (VTE_DEBUG_DRAW)) {
+                GString *string = g_string_new ("");
+                gchar *str;
+                gsize n;
+                for (n = 0; n < n_requests; n++) {
+                        g_string_append_unichar (string, requests[n].c);
+                }
+                str = g_string_free (string, FALSE);
+                g_printerr ("draw_text (\"%s\", len=%" G_GSIZE_FORMAT ", color=(%d,%d,%d), %s - %s)\n",
+                            str, n_requests, color->red, color->green, color->blue,
+                            (attr & VTE_ATTR_BOLD)   ? "bold"   : "normal",
+                            (attr & VTE_ATTR_ITALIC) ? "italic" : "regular");
+                g_free (str);
+        }
+
         auto font = m_fonts[attr_to_style(attr)];
         gsize i;
 
@@ -173,7 +188,7 @@ DrawingGsk::draw_text_internal(TextRequest* requests,
                         vte_bidi_get_mirror_char (c, requests[i].box_mirror, &c);
                 }
 
-                if (m_minifont.unistr_is_local_graphic(c)) {
+                if (Minifont::unistr_is_local_graphic(c)) {
                         m_minifont.draw_graphic(*this,
                                                 c,
                                                 color,
@@ -195,9 +210,10 @@ DrawingGsk::draw_text_internal(TextRequest* requests,
 
                 switch (uinfo->coverage()) {
                 default:
-                case FontInfo::UnistrInfo::Coverage::UNKNOWN:
                         g_assert_not_reached ();
                         break;
+                case FontInfo::UnistrInfo::Coverage::UNKNOWN:
+                        break;
                 case FontInfo::UnistrInfo::Coverage::USE_PANGO_GLYPH_STRING:
                         if (node_font != ufi->using_pango_glyph_string.font) {
                                 flush_glyph_string (node_font, &rgba);
